@@ -2,13 +2,15 @@ package Test::DBIx::Class::Schema;
 {
   $Test::DBIx::Class::Schema::DIST = 'Test-DBIx-Class-Schema';
 }
-$Test::DBIx::Class::Schema::VERSION = '1.0.9';
+$Test::DBIx::Class::Schema::VERSION = '1.0.10';
 # vim: ts=8 sts=4 et sw=4 sr sta
 use strict;
 use warnings;
 
 # ensure we have "done_testing"
-use Test::More 0.92;
+# we also want to be sure we're using the recent enough version to fix a bug
+# in the output (https://github.com/chiselwright/test-dbix-class-schema/issues/12)
+use Test::More 1.302015;
 
 sub new {
     my ($proto, $options) = @_;
@@ -80,9 +82,12 @@ sub run_tests {
 
     # TODO: test custom, resultsets
 
-    my $tb = Test::More->builder;
+    my $ctx = Test::More->builder->ctx;
+    my $tb2_already_done_testing =
+        defined $ctx->snapshot->hub->meta('Test::Builder')->{Done_Testing};
+    $ctx->release;
     done_testing
-        unless ($tb->{Done_Testing} || $ENV{TEST_AGGREGATE});
+        unless ($tb2_already_done_testing || $ENV{TEST_AGGREGATE});
 }
 
 sub _test_normal_methods {
@@ -300,7 +305,7 @@ Test::DBIx::Class::Schema - DBIx::Class schema sanity checking tests
 
 =head1 VERSION
 
-version 1.0.9
+version 1.0.10
 
 =head1 SYNOPSIS
 
@@ -417,13 +422,23 @@ L<DBIx::Class>,
 L<Test::More>,
 L<Test::Aggregate>
 
+=begin markdown
+
+## BUILD STATUS
+
+### master
+
+[![Build status](https://badge.buildkite.com/c8793ab59e31d982dd759cadfb66a308d5278f21cb707d8822.svg?branch=master)](https://buildkite.com/chizography/test-dbix-class-schema)
+
+=end markdown
+
 =head1 AUTHOR
 
 Chisel Wright <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Chisel Wright.
+This software is copyright (c) 2016 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -436,26 +451,10 @@ the same terms as the Perl 5 programming language system itself.
 
 =item *
 
-Chisel <chisel.wright@net-a-porter.com>
-
-=item *
-
-Chisel <chisel@chizography.net>
-
-=item *
-
-Chisel Wright <chisel.wright@net-a-porter.com>
-
-=item *
-
 Chisel Wright <chisel@cleavag.es>
 
 =item *
 
-Chisel Wright <chisel@herlpacker.co.uk>
-
-=item *
-
 Darius Jokilehto <darius.jokilehto@net-a-porter.com>
 
 =item *
